@@ -2,5 +2,7 @@
 # Configuration file for using the XML library in GNOME applications
 #
 XML_LIBDIR="-L/usr/local/lib"
-XML_LIBS="-lxml -lz"
-XML_INCLUDEDIR="-I/usr/local/include"
\ No newline at end of file
+XML_LIBS="-lxml -lz  "
+XML_INCLUDEDIR="-I/usr/local/include/gnome-xml"
+MODULE_VERSION="xml-1.8.17"
+
